Learn R Programming

waveTiling (version 1.14.0)

bgCorrQn: Background correction and quantile normalization

Description

Function to perform background correction and quantile normalization of tiling arrays

Usage

bgCorrQn(object, useMapFilter=NULL)

Arguments

object
object of class WaveTilingFeatureSet
useMapFilter
NULL or object of class mapFilterProbe indicating the probes to use for background correction and quantile normalization

Value

WaveTilingFeatureSet containing the background-corrected and quantile-normalized intensity signals

Examples

Run this code
## Not run: 
#   data(leafdev)
#   leafdev <- as(leafdev,"WaveTilingFeatureSet")
#   data(leafdevMapAndFilterTAIR9)
#   leafdevBQ <- bgCorrQn(leafdev,useMapFilter=leafdevMapAndFilterTAIR9)
# ## End(Not run)

Run the code above in your browser using DataLab